@@ -24,6 +24,7 @@
 #include "config-breeze.h"
 
 #include <QObject>
+#include <QPointer>
 #include <QMap>
 #include <QMargins>
 
@@ -34,11 +35,12 @@
 #if BREEZE_HAVE_KWAYLAND
 namespace KWayland
 {
-namespace Client
-{
-    class ShadowManager;
-    class ShmPool;
-}
+    namespace Client
+    {
+        class ShadowManager;
+        class ShmPool;
+        class Surface;
+    }
 }
 #endif
 
@@ -65,17 +67,17 @@ namespace Breeze
         ShadowHelper( QObject*, Helper& );
 
         //* destructor
-        virtual ~ShadowHelper( void );
+        virtual ~ShadowHelper();
 
         //* true if supported
-        bool isSupported( void ) const
+        bool isSupported() const
         { return _supported; }
 
         //* reset
-        void reset( void );
+        void reset();
 
         //* load config
-        void loadConfig( void );
+        void loadConfig();
 
         //* register widget
         bool registerWidget( QWidget*, bool force = false );
@@ -88,7 +90,7 @@ namespace Breeze
 
         //* shadow tiles
         /** is public because it is also needed for mdi windows */
-        TileSet shadowTiles( void );
+        TileSet shadowTiles();
 
         protected Q_SLOTS:
 
@@ -116,7 +118,7 @@ namespace Breeze
         bool acceptWidget( QWidget* ) const;
 
         // create pixmap handles from tileset
-        const QVector<quint32>& createPixmapHandles( void );
+        const QVector<quint32>& createPixmapHandles();
 
         // create pixmap handle from pixmap
         quint32 createPixmap( const QPixmap& );
@@ -177,10 +179,15 @@ namespace Breeze
         #endif
 
         #if BREEZE_HAVE_KWAYLAND
+
+        //* registered widgets to wayland surface mappings
+        QMap<QWidget*, KWayland::Client::Surface *> _widgetSurfaces;
+
         //* The Wayland shadow manager to create Shadows for Surfaces (QWindow)
-        KWayland::Client::ShadowManager* _shadowManager;
+        QPointer<KWayland::Client::ShadowManager> _shadowManager;
+
         //* The Wayland Shared memory pool to share the shadow pixmaps with compositor
-        KWayland::Client::ShmPool* _shmPool;
+        QPointer<KWayland::Client::ShmPool> _shmPool;
         #endif
 
     };
